@@ -1,10 +1,10 @@
-import logbook
+import logging
 
 from regipy import RegistryKeyNotFoundException, convert_wintime
 from regipy.hive_types import NTUSER_HIVE_TYPE
 from regipy.plugins.plugin import Plugin
 
-logger = logbook.Logger(__name__)
+logger = logging.getLogger(__name__)
 
 CLASSES_INSTALLER_PATH = r'\Software\Classes\Installer\Product'
 
