@@ -12,10 +12,11 @@ from io import TextIOWrapper
 import attr
 import pytz
 
+
 from regipy.exceptions import NoRegistrySubkeysException, RegistryKeyNotFoundException, RegipyGeneralException, \
     UnidentifiedHiveException
 from regipy.hive_types import NTUSER_HIVE_TYPE, SYSTEM_HIVE_TYPE, AMCACHE_HIVE_TYPE, SOFTWARE_HIVE_TYPE, \
-    SAM_HIVE_TYPE
+    SAM_HIVE_TYPE, SECURITY_HIVE_TYPE
 
 logger = logging.getLogger(__name__)
 
@@ -135,6 +136,8 @@ def identify_hive_type(name: str) -> str:
         return SOFTWARE_HIVE_TYPE
     elif hive_name == r'\systemroot\system32\config\sam':
         return SAM_HIVE_TYPE
+    elif hive_name == r'emroot\system32\config\security':
+        return SECURITY_HIVE_TYPE
     elif 'amcache' in hive_name.lower():
         return AMCACHE_HIVE_TYPE
     else:
